@@ -27,6 +27,7 @@ const std::map <llvm::StringRef, hipCounter> CUDA_INCLUDE_MAP {
   // CUDA includes
   {"cuda.h",                                                {"hip/hip_runtime.h",                                     "", CONV_INCLUDE_CUDA_MAIN_H,    API_DRIVER, 0}},
   {"cuda_runtime.h",                                        {"hip/hip_runtime.h",                                     "", CONV_INCLUDE_CUDA_MAIN_H,    API_RUNTIME, 0}},
+  {"device_launch_parameters.h",                            {"",                                                      "", CONV_INCLUDE,                API_RUNTIME, 0}},
   {"cuda_runtime_api.h",                                    {"hip/hip_runtime_api.h",                                 "", CONV_INCLUDE,                API_RUNTIME, 0}},
   {"channel_descriptor.h",                                  {"hip/channel_descriptor.h",                              "", CONV_INCLUDE,                API_RUNTIME, 0}},
   {"device_functions.h",                                    {"hip/device_functions.h",                                "", CONV_INCLUDE,                API_RUNTIME, 0}},
@@ -38,30 +39,32 @@ const std::map <llvm::StringRef, hipCounter> CUDA_INCLUDE_MAP {
   {"cuda_profiler_api.h",                                   {"hip/hip_runtime_api.h",                                 "", CONV_INCLUDE,                API_RUNTIME, 0}},
   {"cooperative_groups.h",                                  {"hip/hip_cooperative_groups.h",                          "", CONV_INCLUDE,                API_RUNTIME, 0}},
   {"library_types.h",                                       {"hip/library_types.h",                                   "", CONV_INCLUDE,                API_RUNTIME, 0}},
+  {"math_constants.h",                                      {"hip/hip_math_constants.h",                              "", CONV_INCLUDE,                API_RUNTIME, 0}},
   // cuComplex includes
   {"cuComplex.h",                                           {"hip/hip_complex.h",                                     "", CONV_INCLUDE_CUDA_MAIN_H,    API_COMPLEX, 0}},
   // cuBLAS includes
   {"cublas.h",                                              {"hipblas.h",                                    "rocblas.h", CONV_INCLUDE_CUDA_MAIN_H,    API_BLAS, 0}},
   {"cublas_v2.h",                                           {"hipblas.h",                                    "rocblas.h", CONV_INCLUDE_CUDA_MAIN_V2_H, API_BLAS, 0}},
   {"cublas_api.h",                                          {"hipblas.h",                                    "rocblas.h", CONV_INCLUDE,                API_BLAS, 0}},
+  {"cublasLt.h",                                            {"hipblaslt.h",                                           "", CONV_INCLUDE,                API_BLAS, 0}},
   // cuRAND includes
-  {"curand.h",                                              {"hiprand/hiprand.h",                                     "", CONV_INCLUDE_CUDA_MAIN_H,    API_RAND, 0}},
-  {"curand_kernel.h",                                       {"hiprand/hiprand_kernel.h",                              "", CONV_INCLUDE,                API_RAND, 0}},
-  {"curand_discrete.h",                                     {"hiprand/hiprand_kernel.h",                              "", CONV_INCLUDE,                API_RAND, 0}},
-  {"curand_discrete2.h",                                    {"hiprand/hiprand_kernel.h",                              "", CONV_INCLUDE,                API_RAND, 0}},
-  {"curand_globals.h",                                      {"hiprand/hiprand_kernel.h",                              "", CONV_INCLUDE,                API_RAND, 0}},
-  {"curand_lognormal.h",                                    {"hiprand/hiprand_kernel.h",                              "", CONV_INCLUDE,                API_RAND, 0}},
-  {"curand_mrg32k3a.h",                                     {"hiprand/hiprand_kernel.h",                              "", CONV_INCLUDE,                API_RAND, 0}},
-  {"curand_mtgp32.h",                                       {"hiprand/hiprand_kernel.h",                              "", CONV_INCLUDE,                API_RAND, 0}},
-  {"curand_mtgp32_host.h",                                  {"hiprand/hiprand_mtgp32_host.h",                         "", CONV_INCLUDE,                API_RAND, 0}},
-  {"curand_mtgp32_kernel.h",                                {"hiprand/hiprand_kernel.h",                              "", CONV_INCLUDE,                API_RAND, 0}},
-  {"curand_mtgp32dc_p_11213.h",                             {"rocrand_mtgp32_11213.h",                                "", CONV_INCLUDE,                API_RAND, 0}},
-  {"curand_normal.h",                                       {"hiprand/hiprand_kernel.h",                              "", CONV_INCLUDE,                API_RAND, 0}},
-  {"curand_normal_static.h",                                {"hiprand/hiprand_kernel.h",                              "", CONV_INCLUDE,                API_RAND, 0}},
-  {"curand_philox4x32_x.h",                                 {"hiprand/hiprand_kernel.h",                              "", CONV_INCLUDE,                API_RAND, 0}},
-  {"curand_poisson.h",                                      {"hiprand/hiprand_kernel.h",                              "", CONV_INCLUDE,                API_RAND, 0}},
-  {"curand_precalc.h",                                      {"hiprand/hiprand_kernel.h",                              "", CONV_INCLUDE,                API_RAND, 0}},
-  {"curand_uniform.h",                                      {"hiprand/hiprand_kernel.h",                              "", CONV_INCLUDE,                API_RAND, 0}},
+  {"curand.h",                                              {"hiprand/hiprand.h",                                     "rocrand/rocrand.h",                                              CONV_INCLUDE_CUDA_MAIN_H,    API_RAND, 0}},
+  {"curand_kernel.h",                                       {"hiprand/hiprand_kernel.h",                              "rocrand/rocrand_kernel.h",                                       CONV_INCLUDE,                API_RAND, 0}},
+  {"curand_discrete.h",                                     {"hiprand/hiprand_kernel.h",                              "rocrand/rocrand_discrete.h",                                     CONV_INCLUDE,                API_RAND, 0}},
+  {"curand_discrete2.h",                                    {"hiprand/hiprand_kernel.h",                              "rocrand/rocrand_discrete.h",                                     CONV_INCLUDE,                API_RAND, 0}},
+  {"curand_globals.h",                                      {"hiprand/hiprand_kernel.h",                              "rocrand/rocrand_common.h",                                       CONV_INCLUDE,                API_RAND, 0}},
+  {"curand_lognormal.h",                                    {"hiprand/hiprand_kernel.h",                              "rocrand/rocrand_log_normal.h",                                   CONV_INCLUDE,                API_RAND, 0}},
+  {"curand_mrg32k3a.h",                                     {"hiprand/hiprand_kernel.h",                              "rocrand/rocrand_mrg32k3a.h",                                     CONV_INCLUDE,                API_RAND, 0}},
+  {"curand_mtgp32.h",                                       {"hiprand/hiprand_kernel.h",                              "rocrand/rocrand_mtgp32.h",                                       CONV_INCLUDE,                API_RAND, 0}},
+  {"curand_mtgp32_host.h",                                  {"hiprand/hiprand_mtgp32_host.h",                         "rocrand/rocrand_mtgp32.h",                                       CONV_INCLUDE,                API_RAND, 0}},
+  {"curand_mtgp32_kernel.h",                                {"hiprand/hiprand_kernel.h",                              "rocrand/rocrand_mtgp32.h",                                       CONV_INCLUDE,                API_RAND, 0}},
+  {"curand_mtgp32dc_p_11213.h",                             {"rocrand/rocrand_mtgp32_11213.h",                        "rocrand/rocrand_mtgp32_11213.h",                                 CONV_INCLUDE,                API_RAND, 0}},
+  {"curand_normal.h",                                       {"hiprand/hiprand_kernel.h",                              "rocrand/rocrand_normal.h",                                       CONV_INCLUDE,                API_RAND, 0}},
+  {"curand_normal_static.h",                                {"hiprand/hiprand_kernel.h",                              "rocrand/rocrand_normal.h",                                       CONV_INCLUDE,                API_RAND, 0}},
+  {"curand_philox4x32_x.h",                                 {"hiprand/hiprand_kernel.h",                              "rocrand/rocrand_philox4x32_10.h",                                CONV_INCLUDE,                API_RAND, 0}},
+  {"curand_poisson.h",                                      {"hiprand/hiprand_kernel.h",                              "rocrand/rocrand_poisson.h",                                      CONV_INCLUDE,                API_RAND, 0}},
+  {"curand_precalc.h",                                      {"hiprand/hiprand_kernel.h",                              "rocrand/rocrand_xorwow_precomputed.h",                           CONV_INCLUDE,                API_RAND, 0}},
+  {"curand_uniform.h",                                      {"hiprand/hiprand_kernel.h",                              "rocrand/rocrand_uniform.h",                                      CONV_INCLUDE,                API_RAND, 0}},
   // cuDNN includes
   {"cudnn.h",                                               {"hipDNN.h",                               "miopen/miopen.h", CONV_INCLUDE_CUDA_MAIN_H,    API_DNN, 0}},
   // cuFFT includes
