@@ -131,13 +131,16 @@ const std::map<llvm::StringRef, cudaAPIversions> &CUDA_VERSIONS_MAP();
 
 extern const std::map<llvm::StringRef, hipAPIversions> HIP_DRIVER_TYPE_NAME_VER_MAP;
 extern const std::map<llvm::StringRef, hipAPIversions> HIP_DRIVER_FUNCTION_VER_MAP;
+extern const std::map<llvm::StringRef, cudaAPIChangedVersions> CUDA_DRIVER_FUNCTION_CHANGED_VER_MAP;
 extern const std::map<llvm::StringRef, hipAPIversions> HIP_RUNTIME_TYPE_NAME_VER_MAP;
 extern const std::map<llvm::StringRef, hipAPIversions> HIP_RUNTIME_FUNCTION_VER_MAP;
+extern const std::map<llvm::StringRef, cudaAPIChangedVersions> CUDA_RUNTIME_FUNCTION_CHANGED_VER_MAP;
 extern const std::map<llvm::StringRef, hipAPIversions> HIP_COMPLEX_TYPE_NAME_VER_MAP;
 extern const std::map<llvm::StringRef, hipAPIversions> HIP_COMPLEX_FUNCTION_VER_MAP;
 extern const std::map<llvm::StringRef, hipAPIversions> HIP_BLAS_TYPE_NAME_VER_MAP;
 extern const std::map<llvm::StringRef, hipAPIversions> HIP_BLAS_FUNCTION_VER_MAP;
 extern const std::map<llvm::StringRef, hipAPIChangedVersions> HIP_BLAS_FUNCTION_CHANGED_VER_MAP;
+extern const std::map<llvm::StringRef, cudaAPIChangedVersions> CUDA_BLAS_FUNCTION_CHANGED_VER_MAP;
 extern const std::map<llvm::StringRef, hipAPIversions> HIP_RAND_TYPE_NAME_VER_MAP;
 extern const std::map<llvm::StringRef, hipAPIversions> HIP_RAND_FUNCTION_VER_MAP;
 extern const std::map<llvm::StringRef, hipAPIversions> HIP_DNN_TYPE_NAME_VER_MAP;
@@ -164,7 +167,7 @@ extern const std::map<llvm::StringRef, hipAPIversions> HIP_SOLVER_FUNCTION_VER_M
   * The union of all the above HIP maps.
   *
   */
-const std::map<llvm::StringRef, hipAPIversions>& HIP_VERSIONS_MAP();
+const std::map<llvm::StringRef, hipAPIversions> &HIP_VERSIONS_MAP();
 
 extern const std::map<unsigned int, llvm::StringRef> CUDA_DRIVER_API_SECTION_MAP;
 extern const std::map<unsigned int, llvm::StringRef> CUDA_RUNTIME_API_SECTION_MAP;
@@ -215,55 +218,72 @@ namespace driver {
     GRAPHICS = 32,
     DRIVER_ENTRY_POINT = 33,
     COREDUMP = 34,
-    PROFILER_DEPRECATED = 35,
-    PROFILER = 36,
-    OPENGL = 37,
-    D3D9 = 38,
-    D3D10 = 39,
-    D3D11 = 40,
-    VDPAU = 41,
-    EGL = 42,
+    GREEN_CONTEXT = 35,
+    PROFILER_DEPRECATED = 36,
+    PROFILER = 37,
+    OPENGL = 38,
+    D3D9 = 39,
+    D3D10 = 40,
+    D3D11 = 41,
+    VDPAU = 42,
+    EGL = 43,
   };
 }
 
 namespace runtime {
   enum CUDA_RUNTIME_API_SECTIONS {
     DEVICE = 1,
-    THREAD_DEPRECATED = 2,
-    ERROR = 3,
-    STREAM = 4,
-    EVENT = 5,
-    EXTERNAL_RES = 6,
-    EXECUTION = 7,
-    OCCUPANCY = 8,
-    MEMORY = 9,
-    MEMORY_DEPRECATED = 10,
-    ORDERED_MEMORY = 11,
-    UNIFIED = 12,
-    PEER = 13,
-    OPENGL = 14,
-    OPENGL_DEPRECATED = 15,
-    D3D9 = 16,
-    D3D9_DEPRECATED = 17,
-    D3D10 = 18,
-    D3D10_DEPRECATED = 19,
-    D3D11 = 20,
-    D3D11_DEPRECATED = 21,
-    VDPAU = 22,
-    EGL = 23,
-    GRAPHICS = 24,
-    TEXTURE = 25,
-    SURFACE = 26,
-    VERSION = 27,
-    GRAPH = 28,
-    DRIVER_ENTRY_POINT = 29,
-    CPP = 30,
-    DRIVER_INTERACT = 31,
-    PROFILER = 32,
-    DATA_TYPES = 33,
-    EXECUTION_REMOVED = 34,
-    TEXTURE_REMOVED = 35,
-    SURFACE_REMOVED = 36,
-    PROFILER_REMOVED = 37,
+    DEVICE_DEPRECATED = 2,
+    THREAD_DEPRECATED = 3,
+    ERROR = 4,
+    STREAM = 5,
+    EVENT = 6,
+    EXTERNAL_RES = 7,
+    EXECUTION = 8,
+    EXECUTION_DEPRECATED = 9,
+    OCCUPANCY = 10,
+    MEMORY = 11,
+    MEMORY_DEPRECATED = 12,
+    ORDERED_MEMORY = 13,
+    UNIFIED = 14,
+    PEER = 15,
+    OPENGL = 16,
+    OPENGL_DEPRECATED = 17,
+    D3D9 = 18,
+    D3D9_DEPRECATED = 19,
+    D3D10 = 20,
+    D3D10_DEPRECATED = 21,
+    D3D11 = 22,
+    D3D11_DEPRECATED = 23,
+    VDPAU = 24,
+    EGL = 25,
+    GRAPHICS = 26,
+    TEXTURE = 27,
+    SURFACE = 28,
+    VERSION = 29,
+    GRAPH = 30,
+    DRIVER_ENTRY_POINT = 31,
+    CPP = 32,
+    DRIVER_INTERACT = 33,
+    PROFILER = 34,
+    DATA_TYPES = 35,
+    EXECUTION_REMOVED = 36,
+    TEXTURE_REMOVED = 37,
+    SURFACE_REMOVED = 38,
+    PROFILER_REMOVED = 39,
+  };
+}
+
+namespace blas {
+  enum BLAS_API_SECTIONS {
+    BLAS_DATA_TYPES = 1,
+    CUDA_DATA_TYPES = 2,
+    BLAS_LT_DATA_TYPES = 3,
+    BLAS_HELPER = 4,
+    BLAS_LEVEL_1 = 5,
+    BLAS_LEVEL_2 = 6,
+    BLAS_LEVEL_3 = 7,
+    BLAS_EXT = 8,
+    BLAS_LT = 9,
   };
 }
