@@ -87,6 +87,11 @@ namespace doc {
   const string sRAND = "CURAND_API_supported_by_HIP";
   const string sRAND_md = sRAND + md_ext;
   const string sRAND_csv = sRAND + csv_ext;
+  const string sRAND_and_ROC_md = sRAND + sandROC + md_ext;
+  const string sRAND_and_ROC_csv = sRAND + sandROC + csv_ext;
+  const string sROCRAND = "CURAND_API_supported_by_ROC";
+  const string sROCRAND_md = sROCRAND + md_ext;
+  const string sROCRAND_csv = sROCRAND + csv_ext;
   const string sCURAND = "CURAND";
 
   const string sandMIOPEN = "_and_MIOPEN";
@@ -477,6 +482,7 @@ namespace doc {
       const typeMap &getTypes() const override { return CUDA_DRIVER_TYPE_NAME_MAP; }
       const versionMap &getFunctionVersions() const override { return CUDA_DRIVER_FUNCTION_VER_MAP; }
       const hipVersionMap &getHipFunctionVersions() const override { return HIP_DRIVER_FUNCTION_VER_MAP; }
+      const cudaChangedVersionMap &getCudaChangedFunctionVersions() const override { return CUDA_DRIVER_FUNCTION_CHANGED_VER_MAP; }
       const versionMap &getTypeVersions() const override { return CUDA_DRIVER_TYPE_NAME_VER_MAP; }
       const hipVersionMap &getHipTypeVersions() const override { return HIP_DRIVER_TYPE_NAME_VER_MAP; }
       const string &getName() const override { return sCUDA_DRIVER; }
@@ -506,6 +512,7 @@ namespace doc {
       const typeMap &getTypes() const override { return CUDA_RUNTIME_TYPE_NAME_MAP; }
       const versionMap &getFunctionVersions() const override { return CUDA_RUNTIME_FUNCTION_VER_MAP; }
       const hipVersionMap &getHipFunctionVersions() const override { return HIP_RUNTIME_FUNCTION_VER_MAP; }
+      const cudaChangedVersionMap& getCudaChangedFunctionVersions() const override { return CUDA_RUNTIME_FUNCTION_CHANGED_VER_MAP; }
       const versionMap &getTypeVersions() const override { return CUDA_RUNTIME_TYPE_NAME_VER_MAP; }
       const hipVersionMap &getHipTypeVersions() const override { return HIP_RUNTIME_TYPE_NAME_VER_MAP; }
       const string &getName() const override { return sCUDA_RUNTIME; }
@@ -559,6 +566,7 @@ namespace doc {
       const versionMap &getFunctionVersions() const override { return CUDA_BLAS_FUNCTION_VER_MAP; }
       const hipVersionMap &getHipFunctionVersions() const override { return HIP_BLAS_FUNCTION_VER_MAP; }
       const hipChangedVersionMap &getHipChangedFunctionVersions() const override { return HIP_BLAS_FUNCTION_CHANGED_VER_MAP; }
+      const cudaChangedVersionMap &getCudaChangedFunctionVersions() const override { return CUDA_BLAS_FUNCTION_CHANGED_VER_MAP; }
       const versionMap &getTypeVersions() const override { return CUDA_BLAS_TYPE_NAME_VER_MAP; }
       const hipVersionMap &getHipTypeVersions() const override { return HIP_BLAS_TYPE_NAME_VER_MAP; }
       const string &getName() const override { return sCUBLAS; }
@@ -592,20 +600,20 @@ namespace doc {
 
   class SOLVER : public DOC {
   public:
-    SOLVER(const string& outDir) : DOC(outDir) { hasROC = true; }
+    SOLVER(const string &outDir) : DOC(outDir) { hasROC = true; }
     virtual ~SOLVER() {}
   protected:
-    const sectionMap& getSections() const override { return CUDA_SOLVER_API_SECTION_MAP; }
-    const functionMap& getFunctions() const override { return CUDA_SOLVER_FUNCTION_MAP; }
-    const typeMap& getTypes() const override { return CUDA_SOLVER_TYPE_NAME_MAP; }
-    const versionMap& getFunctionVersions() const override { return CUDA_SOLVER_FUNCTION_VER_MAP; }
-    const hipVersionMap& getHipFunctionVersions() const override { return HIP_SOLVER_FUNCTION_VER_MAP; }
-    const versionMap& getTypeVersions() const override { return CUDA_SOLVER_TYPE_NAME_VER_MAP; }
-    const hipVersionMap& getHipTypeVersions() const override { return HIP_SOLVER_TYPE_NAME_VER_MAP; }
-    const string& getName() const override { return sCUSOLVER; }
-    const string& getSecondAPI() const override { return sROC; }
-    const string& getJointAPI() const override { return sHIPandROC; }
-    const string& getFileName(docType format) const override {
+    const sectionMap &getSections() const override { return CUDA_SOLVER_API_SECTION_MAP; }
+    const functionMap &getFunctions() const override { return CUDA_SOLVER_FUNCTION_MAP; }
+    const typeMap &getTypes() const override { return CUDA_SOLVER_TYPE_NAME_MAP; }
+    const versionMap &getFunctionVersions() const override { return CUDA_SOLVER_FUNCTION_VER_MAP; }
+    const hipVersionMap &getHipFunctionVersions() const override { return HIP_SOLVER_FUNCTION_VER_MAP; }
+    const versionMap &getTypeVersions() const override { return CUDA_SOLVER_TYPE_NAME_VER_MAP; }
+    const hipVersionMap &getHipTypeVersions() const override { return HIP_SOLVER_TYPE_NAME_VER_MAP; }
+    const string &getName() const override { return sCUSOLVER; }
+    const string &getSecondAPI() const override { return sROC; }
+    const string &getJointAPI() const override { return sHIPandROC; }
+    const string &getFileName(docType format) const override {
       switch (format) {
       case none:
       default: return sEmpty;
@@ -617,11 +625,11 @@ namespace doc {
 
   class ROCSOLVER : public SOLVER {
   public:
-    ROCSOLVER(const string& outDir) : SOLVER(outDir) { hasROC = false; isROC = true; }
+    ROCSOLVER(const string &outDir) : SOLVER(outDir) { hasROC = false; isROC = true; }
     virtual ~ROCSOLVER() {}
   protected:
-    const string& getAPI() const override { return sROC; }
-    const string& getFileName(docType format) const override {
+    const string &getAPI() const override { return sROC; }
+    const string &getFileName(docType format) const override {
       switch (format) {
       case none:
       default: return sEmpty;
@@ -633,7 +641,7 @@ namespace doc {
 
   class RAND: public DOC {
     public:
-      RAND(const string &outDir): DOC(outDir) {}
+      RAND(const string &outDir): DOC(outDir) { hasROC = true; }
       virtual ~RAND() {}
     protected:
       const sectionMap &getSections() const override { return CUDA_RAND_API_SECTION_MAP; }
@@ -645,12 +653,28 @@ namespace doc {
       const hipVersionMap &getHipTypeVersions() const override { return HIP_RAND_TYPE_NAME_VER_MAP; }
       const string &getName() const override { return sCURAND; }
       const string &getFileName(docType format) const override {
-        switch (format) {
+          switch (format) {
           case none:
           default: return sEmpty;
-          case md: return sRAND_md;
-          case csv: return sRAND_csv;
-        }
+          case md: return roc == joint ? sRAND_and_ROC_md : sRAND_md;
+          case csv: return roc == joint ? sRAND_and_ROC_csv : sRAND_csv;
+          }
+      }
+  };
+
+  class ROCRAND : public RAND {
+  public:
+      ROCRAND(const string& outDir) : RAND(outDir) { hasROC = false; isROC = true; }
+      virtual ~ROCRAND() {}
+  protected:
+      const string& getAPI() const override { return sROC; }
+      const string& getFileName(docType format) const override {
+          switch (format) {
+          case none:
+          default: return sEmpty;
+          case md: return sROCRAND_md;
+          case csv: return sROCRAND_csv;
+          }
       }
   };
 
@@ -875,14 +899,16 @@ namespace doc {
     ROCSOLVER rocsolver(sOut);
     MIOPEN miopen(sOut);
     ROCSPARSE rocsparse(sOut);
+    RAND rand(sOut);
+    docs.addDoc(&rand);
+    ROCRAND rocrand(sOut);
     if (docRoc == separate) {
       docs.addDoc(&rocblas);
+      docs.addDoc(&rocrand);
       docs.addDoc(&miopen);
       docs.addDoc(&rocsparse);
       docs.addDoc(&rocsolver);
     }
-    RAND rand(sOut);
-    docs.addDoc(&rand);
     DNN dnn(sOut);
     docs.addDoc(&dnn);
     FFT fft(sOut);
