@@ -22,6 +22,7 @@ THE SOFTWARE.
 
 #include <algorithm>
 #include <set>
+#include <string>
 #include "HipifyAction.h"
 #include "CUDA2HIP_Scripting.h"
 #include "clang/Basic/SourceLocation.h"
@@ -44,11 +45,15 @@ const std::string sHIP_KERNEL_NAME = "HIP_KERNEL_NAME";
 std::string sHIP_SYMBOL = "HIP_SYMBOL";
 std::string s_reinterpret_cast = "reinterpret_cast<const void*>";
 std::string s_reinterpret_cast_size_t = "reinterpret_cast<size_t*>";
+std::string s_static_cast_uint64_t = "static_cast<uint64_t>";
 std::string s_int32_t = "int32_t";
 std::string s_int64_t = "int64_t";
 const std::string sHipLaunchKernelGGL = "hipLaunchKernelGGL";
 const std::string sDim3 = "dim3(";
 const std::string s_hiprand_kernel_h = "hiprand/hiprand_kernel.h";
+const std::string s_rocrand_discrete_t = "rocrand/rocrand_discrete.h";
+const std::string s_rocrand_mtgp32_t = "rocrand/rocrand_mtgp32.h";
+const std::string s_rocrand_normal_t = "rocrand/rocrand_normal.h";
 const std::string s_hiprand_h = "hiprand/hiprand.h";
 const std::string sOnce = "once";
 const std::string s_string_literal = "[string literal]";
@@ -59,6 +64,12 @@ const std::string sCudaGetSymbolSize = "cudaGetSymbolSize";
 const std::string sCudaGetSymbolAddress = "cudaGetSymbolAddress";
 const std::string sCudaMemcpyFromSymbol = "cudaMemcpyFromSymbol";
 const std::string sCudaMemcpyFromSymbolAsync = "cudaMemcpyFromSymbolAsync";
+const std::string sCudaFuncSetCacheConfig = "cudaFuncSetCacheConfig";
+const std::string sCudaFuncSetSharedMemConfig = "cudaFuncSetSharedMemConfig";
+const std::string sCudaFuncGetAttributes = "cudaFuncGetAttributes";
+const std::string sCudaFuncSetAttribute = "cudaFuncSetAttribute";
+const std::string sCudaLaunchKernelStr = "cudaLaunchKernel";
+const std::string sCudaLaunchCooperativeKernel = "cudaLaunchCooperativeKernel";
 const std::string sCudaGraphAddMemcpyNodeToSymbol = "cudaGraphAddMemcpyNodeToSymbol";
 const std::string sCudaGraphAddMemcpyNodeFromSymbol = "cudaGraphAddMemcpyNodeFromSymbol";
 const std::string sCudaGraphMemcpyNodeSetParamsToSymbol = "cudaGraphMemcpyNodeSetParamsToSymbol";
@@ -220,6 +231,7 @@ const std::string sCusparseSpMV = "cusparseSpMV";
 const std::string sCusparseSpMV_bufferSize = "cusparseSpMV_bufferSize";
 const std::string sCusparseSpMM_preprocess = "cusparseSpMM_preprocess";
 const std::string sCusparseSpSV_bufferSize = "cusparseSpSV_bufferSize";
+const std::string sCudaGetDriverEntryPoint = "cudaGetDriverEntryPoint";
 
 // CUDA_OVERLOADED
 const std::string sCudaEventCreate = "cudaEventCreate";
@@ -240,6 +252,7 @@ std::string getCastType(hipify::CastTypes c) {
     case e_HIP_SYMBOL: return sHIP_SYMBOL;
     case e_reinterpret_cast: return s_reinterpret_cast;
     case e_reinterpret_cast_size_t: return s_reinterpret_cast_size_t;
+    case e_static_cast_uint64_t: return s_static_cast_uint64_t;
     case e_int32_t: return s_int32_t;
     case e_int64_t: return s_int64_t;
     case e_remove_argument: return "";
@@ -277,11 +290,74 @@ std::map<std::string, hipify::FuncOverloadsStruct> FuncOverloads {
 };
 
 std::map<std::string, std::vector<ArgCastStruct>> FuncArgCasts {
+  {sCudaGetDriverEntryPoint,
+    {
+      {
+        {
+          {2, {e_add_const_argument, cw_None, std::to_string(int(HIP_LATEST / 10))}}
+        }
+      }
+    }
+  },
+  {sCudaFuncSetCacheConfig,
+    {
+      {
+        {
+          {0, {e_reinterpret_cast, cw_None}}
+        }
+      }
+    }
+  },
+  {sCudaFuncSetSharedMemConfig,
+    {
+      {
+        {
+          {0, {e_reinterpret_cast, cw_None}}
+        }
+      }
+    }
+  },
+  {sCudaFuncGetAttributes,
+    {
+      {
+        {
+          {1, {e_reinterpret_cast, cw_None}}
+        }
+      }
+    }
+  },
+  {sCudaFuncSetAttribute,
+    {
+      {
+        {
+          {0, {e_reinterpret_cast, cw_None}}
+        }
+      }
+    }
+  },
+  {sCudaLaunchKernelStr,
+    {
+      {
+        {
+          {0, {e_reinterpret_cast, cw_None}}
+        }
+      }
+    }
+  },
+  {sCudaLaunchCooperativeKernel,
+    {
+      {
+        {
+          {0, {e_reinterpret_cast, cw_None}}
+        }
+      }
+    }
+  },
   {sCudaMallocHost,
     {
       {
         {
-          {2, {e_add_const_argument, cw_None, "hipHostMallocDefault"}}
+          {3, {e_add_const_argument, cw_None, "hipHostMallocDefault"}}
         }
       }
     }
@@ -2182,7 +2258,7 @@ clang::SourceLocation HipifyAction::GetSubstrLocation(const std::string &str, co
 void HipifyAction::RewriteToken(const clang::Token &t) {
   if (!HipifyAMAP) {
     clang::SourceRange sr(t.getLocation());
-    for (const auto& skipped : SkippedSourceRanges) {
+    for (const auto &skipped : SkippedSourceRanges) {
       if (skipped.fullyContains(sr))
         return;
     }
@@ -2218,7 +2294,7 @@ void HipifyAction::FindAndReplace(StringRef name,
     DE.Report(sl, ID) << found->first;
   }
   // Warn about the unsupported experimental identifier.
-  if (Statistics::isHipExperimental(found->second) &&!Experimental) {
+  if (Statistics::isHipExperimental(found->second) && !Experimental) {
     std::string sWarn;
     Statistics::isToRoc(found->second) ? sWarn = sROC : sWarn = sHIP;
     sWarn = "" + sWarn;
@@ -2276,7 +2352,7 @@ clang::SourceRange getWriteRange(clang::SourceManager &SM, const clang::SourceRa
   // If the range is contained within a macro, update the macro definition.
   // Otherwise, use the file location and hope for the best.
   if (!SM.isMacroBodyExpansion(begin) || !SM.isMacroBodyExpansion(end)) {
-    return {SM.getExpansionLoc(begin), SM.getExpansionLoc(end)};
+    return {SM.getFileLoc(begin), SM.getFileLoc(end)};
   }
   return {SM.getSpellingLoc(begin), SM.getSpellingLoc(end)};
 }
@@ -2310,15 +2386,18 @@ bool HipifyAction::Exclude(const hipCounter &hipToken) {
           insertedBLASHeader = true;
           return false;
         case API_RAND:
-          if (hipToken.hipName == s_hiprand_kernel_h) {
-            if (insertedRAND_kernelHeader) return true;
-            insertedRAND_kernelHeader = true;
-            return false;
-          } else if (hipToken.hipName == s_hiprand_h) {
-            if (insertedRANDHeader) return true;
-            insertedRANDHeader = true;
-            return false;
+          if (!Statistics::isToRoc(hipToken)) {
+            if (hipToken.hipName == s_hiprand_kernel_h) {
+              if (insertedRAND_kernelHeader) return true;
+              insertedRAND_kernelHeader = true;
+              return false;
+            } else if (hipToken.hipName == s_hiprand_h) {
+              if (insertedRANDHeader) return true;
+              insertedRANDHeader = true;
+              return false;
+            }
           }
+          return false;
         case API_DNN:
           if (insertedDNNHeader) return true;
           insertedDNNHeader = true;
@@ -2363,9 +2442,23 @@ bool HipifyAction::Exclude(const hipCounter &hipToken) {
       if (hipToken.hipName.empty()) return true;
       switch (hipToken.apiType) {
         case API_RAND:
-          if (hipToken.hipName == s_hiprand_kernel_h) {
-            if (insertedRAND_kernelHeader) return true;
-            insertedRAND_kernelHeader = true;
+          if (Statistics::isToRoc(hipToken)) {
+            if (hipToken.rocName == s_rocrand_discrete_t) {
+              if (insertedRocRAND_discreteHeader) return true;
+              insertedRocRAND_discreteHeader = true;
+            } else if (hipToken.rocName == s_rocrand_mtgp32_t) {
+              if (insertedRocRAND_mtgp32Header) return true;
+              insertedRocRAND_mtgp32Header = true;
+            } else if (hipToken.rocName == s_rocrand_normal_t) {
+              if (insertedRocRAND_normalHeader) return true;
+              insertedRocRAND_normalHeader = true;
+            }
+          }
+          else {
+            if (hipToken.hipName == s_hiprand_kernel_h) {
+              if (insertedRAND_kernelHeader) return true;
+              insertedRAND_kernelHeader = true;
+            }
           }
           return false;
         default:
@@ -2447,9 +2540,9 @@ bool HipifyAction::cudaLaunchKernel(const mat::MatchFinder::MatchResult &Result)
   clang::SmallString<40> XStr;
   llvm::raw_svector_ostream OS(XStr);
   clang::LangOptions DefaultLangOptions;
-  auto *SM = Result.SourceManager;
+  auto &SM = *Result.SourceManager;
   clang::SourceRange sr = calleeExpr->getSourceRange();
-  std::string kern = readSourceText(*SM, sr).str();
+  std::string kern = readSourceText(SM, sr).str();
   OS << sHipLaunchKernelGGL << "(";
   if (caleeDecl->isTemplateInstantiation()) {
     OS << sHIP_KERNEL_NAME << "(";
@@ -2473,13 +2566,13 @@ bool HipifyAction::cudaLaunchKernel(const mat::MatchFinder::MatchResult &Result)
   // Next up are the four kernel configuration parameters, the last two of which are optional and default to zero.
   // Copy the two dimensional arguments verbatim.
   for (unsigned int i = 0; i < 2; ++i) {
-    const std::string sArg = readSourceText(*SM, config->getArg(i)->getSourceRange()).str();
+    const std::string sArg = readSourceText(SM, config->getArg(i)->getSourceRange()).str();
     bool bDim3 = std::equal(sDim3.begin(), sDim3.end(), sArg.c_str());
     OS << (bDim3 ? "" : sDim3) << sArg << (bDim3 ? "" : ")") << ", ";
   }
   // The stream/memory arguments default to zero if omitted.
-  OS << stringifyZeroDefaultedArg(*SM, config->getArg(2)) << ", ";
-  OS << stringifyZeroDefaultedArg(*SM, config->getArg(3));
+  OS << stringifyZeroDefaultedArg(SM, config->getArg(2)) << ", ";
+  OS << stringifyZeroDefaultedArg(SM, config->getArg(3));
   // If there are ordinary arguments to the kernel, just copy them verbatim into our new call.
   int numArgs = launchKernel->getNumArgs();
   if (numArgs > 0) {
@@ -2488,21 +2581,21 @@ bool HipifyAction::cudaLaunchKernel(const mat::MatchFinder::MatchResult &Result)
     clang::SourceLocation argStart = llcompat::getBeginLoc(launchKernel->getArg(0));
     // End of the last argument.
     clang::SourceLocation argEnd = llcompat::getEndLoc(launchKernel->getArg(numArgs - 1));
-    OS << readSourceText(*SM, {argStart, argEnd});
+    OS << readSourceText(SM, {argStart, argEnd});
   }
   OS << ")";
   clang::SourceLocation launchKernelExprLocBeg = launchKernel->getExprLoc();
-  clang::SourceLocation launchKernelExprLocEnd = launchKernelExprLocBeg.isMacroID() ? llcompat::getEndOfExpansionRangeForLoc(*SM, launchKernelExprLocBeg) : llcompat::getEndLoc(launchKernel);
+  clang::SourceLocation launchKernelExprLocEnd = launchKernelExprLocBeg.isMacroID() ? llcompat::getEndOfExpansionRangeForLoc(SM, launchKernelExprLocBeg) : llcompat::getEndLoc(launchKernel);
   clang::SourceLocation launchKernelEnd = llcompat::getEndLoc(launchKernel);
-  clang::BeforeThanCompare<clang::SourceLocation> isBefore(*SM);
+  clang::BeforeThanCompare<clang::SourceLocation> isBefore(SM);
   launchKernelExprLocEnd = isBefore(launchKernelEnd, launchKernelExprLocEnd) ? launchKernelExprLocEnd : launchKernelEnd;
-  clang::SourceRange replacementRange = getWriteRange(*SM, {launchKernelExprLocBeg, launchKernelExprLocEnd});
+  clang::SourceRange replacementRange = getWriteRange(SM, {launchKernelExprLocBeg, launchKernelExprLocEnd});
   clang::SourceLocation launchBeg = replacementRange.getBegin();
   clang::SourceLocation launchEnd = replacementRange.getEnd();
   if (isBefore(launchBeg, launchEnd)) {
-    size_t length = SM->getCharacterData(clang::Lexer::getLocForEndOfToken(launchEnd, 0, *SM, DefaultLangOptions)) - SM->getCharacterData(launchBeg);
-    ct::Replacement Rep(*SM, launchBeg, length, OS.str());
-    clang::FullSourceLoc fullSL(launchBeg, *SM);
+    size_t length = SM.getCharacterData(clang::Lexer::getLocForEndOfToken(launchEnd, 0, SM, DefaultLangOptions)) - SM.getCharacterData(launchBeg);
+    ct::Replacement Rep(SM, launchBeg, length, OS.str());
+    clang::FullSourceLoc fullSL(launchBeg, SM);
     insertReplacement(Rep, fullSL);
     hipCounter counter = {sHipLaunchKernelGGL, "", ConvTypes::CONV_KERNEL_LAUNCH, ApiTypes::API_RUNTIME};
     Statistics::current().incrementCounter(counter, sCudaLaunchKernel.str());
@@ -2587,6 +2680,7 @@ bool HipifyAction::cudaHostFuncCall(const mat::MatchFinder::MatchResult &Result)
     auto it = FuncArgCasts.find(sName);
     if (it == FuncArgCasts.end()) return false;
     auto castStructs = it->second;
+    auto &SM = *Result.SourceManager;
     for (auto cc : castStructs) {
       if (cc.isToMIOpen != TranslateToMIOpen || cc.isToRoc != TranslateToRoc) continue;
       clang::LangOptions DefaultLangOptions;
@@ -2595,17 +2689,17 @@ bool HipifyAction::cudaHostFuncCall(const mat::MatchFinder::MatchResult &Result)
         unsigned int argNum = c.first;
         clang::SmallString<40> XStr;
         llvm::raw_svector_ostream OS(XStr);
-        auto *SM = Result.SourceManager;
         clang::SourceRange sr, replacementRange;
         clang::SourceLocation s, e;
         if (argNum < call->getNumArgs()) {
           sr = call->getArg(argNum)->getSourceRange();
-          replacementRange = getWriteRange(*SM, { sr.getBegin(), sr.getEnd() });
-          s = replacementRange.getBegin();
-          e = replacementRange.getEnd();
+          replacementRange = getWriteRange(SM, { sr.getBegin(), sr.getEnd() });
         } else {
           s = e = call->getEndLoc();
+          replacementRange = getWriteRange(SM, { s, e });
         }
+        s = replacementRange.getBegin();
+        e = replacementRange.getEnd();
         switch (c.second.castType) {
           case e_remove_argument:
           {
@@ -2616,13 +2710,15 @@ bool HipifyAction::cudaHostFuncCall(const mat::MatchFinder::MatchResult &Result)
             else {
               e = call->getEndLoc();
               if (call->getNumArgs() > 1) {
-                auto prevComma = clang::Lexer::findNextToken(call->getArg(argNum - 1)->getSourceRange().getEnd(), *SM, DefaultLangOptions);
+                auto prevComma = clang::Lexer::findNextToken(call->getArg(argNum - 1)->getSourceRange().getEnd(), SM, DefaultLangOptions);
                 if (!prevComma)
                   s = call->getEndLoc();
                 s = prevComma->getLocation();
               }
             }
-            length = SM->getCharacterData(e) - SM->getCharacterData(s);
+            replacementRange = getWriteRange(SM, { s, e });
+            e = replacementRange.getEnd();
+            length = SM.getCharacterData(e) - SM.getCharacterData(s);
             break;
           }
           case e_move_argument:
@@ -2636,7 +2732,7 @@ bool HipifyAction::cudaHostFuncCall(const mat::MatchFinder::MatchResult &Result)
               sr = call->getArg(argNum + c.second.numberToMoveOrCopy - 1)->getSourceRange();
               sr.setBegin(call->getArg(argNum)->getBeginLoc());
             }
-            sArg = readSourceText(*SM, sr).str();
+            sArg = readSourceText(SM, sr).str();
             if (c.second.moveOrCopyTo < call->getNumArgs())
               dst_OS << sArg << ", ";
             else
@@ -2646,15 +2742,17 @@ bool HipifyAction::cudaHostFuncCall(const mat::MatchFinder::MatchResult &Result)
               dst_s = call->getArg(c.second.moveOrCopyTo)->getBeginLoc();
             else
               dst_s = call->getEndLoc();
-            ct::Replacement dst_Rep(*SM, dst_s, 0, dst_OS.str());
-            clang::FullSourceLoc dst_fullSL(dst_s, *SM);
+            ct::Replacement dst_Rep(SM, dst_s, 0, dst_OS.str());
+            clang::FullSourceLoc dst_fullSL(dst_s, SM);
             insertReplacement(dst_Rep, dst_fullSL);
             OS << "";
             if (argNum < call->getNumArgs())
               e = call->getArg(argNum + c.second.numberToMoveOrCopy)->getBeginLoc();
             else
               e = call->getEndLoc();
-            length = SM->getCharacterData(e) - SM->getCharacterData(s);
+            replacementRange = getWriteRange(SM, { s, e });
+            e = replacementRange.getEnd();
+            length = SM.getCharacterData(e) - SM.getCharacterData(s);
             break;
           }
           case e_add_const_argument:
@@ -2671,7 +2769,7 @@ bool HipifyAction::cudaHostFuncCall(const mat::MatchFinder::MatchResult &Result)
               continue;
             sr = call->getArg(argNum)->getSourceRange();
             sr.setBegin(call->getArg(argNum)->getBeginLoc());
-            std::string sArg = readSourceText(*SM, sr).str();
+            std::string sArg = readSourceText(SM, sr).str();
             if (c.second.moveOrCopyTo < call->getNumArgs()) {
               OS << sArg << ", ";
               s = call->getArg(c.second.moveOrCopyTo)->getBeginLoc();
@@ -2687,16 +2785,16 @@ bool HipifyAction::cudaHostFuncCall(const mat::MatchFinder::MatchResult &Result)
             if (argNum >= call->getNumArgs())
               break;
             OS << c.second.constValToAddOrReplace;
-            length = SM->getCharacterData(clang::Lexer::getLocForEndOfToken(e, 0, *SM, DefaultLangOptions)) - SM->getCharacterData(s);
+            length = SM.getCharacterData(clang::Lexer::getLocForEndOfToken(e, 0, SM, DefaultLangOptions)) - SM.getCharacterData(s);
             break;
           }
           default:
-            OS << getCastType(c.second.castType) << "(" << readSourceText(*SM, sr) << ")";
-            length = SM->getCharacterData(clang::Lexer::getLocForEndOfToken(e, 0, *SM, DefaultLangOptions)) - SM->getCharacterData(s);
+            OS << getCastType(c.second.castType) << "(" << readSourceText(SM, sr) << ")";
+            length = SM.getCharacterData(clang::Lexer::getLocForEndOfToken(e, 0, SM, DefaultLangOptions)) - SM.getCharacterData(s);
             break;
         }
-        ct::Replacement Rep(*SM, s, length, OS.str());
-        clang::FullSourceLoc fullSL(s, *SM);
+        ct::Replacement Rep(SM, s, length, OS.str());
+        clang::FullSourceLoc fullSL(s, SM);
         insertReplacement(Rep, fullSL);
         switch (c.second.castWarn) {
           case cw_DataLoss: {
@@ -2716,9 +2814,9 @@ bool HipifyAction::cudaHostFuncCall(const mat::MatchFinder::MatchResult &Result)
 }
 
 bool HipifyAction::cudaOverloadedHostFuncCall(const mat::MatchFinder::MatchResult& Result) {
-  if (auto* call = Result.Nodes.getNodeAs<clang::CallExpr>(sCudaOverloadedHostFuncCall)) {
+  if (auto *call = Result.Nodes.getNodeAs<clang::CallExpr>(sCudaOverloadedHostFuncCall)) {
     if (!call->getNumArgs()) return false;
-    auto* funcDcl = call->getDirectCallee();
+    auto *funcDcl = call->getDirectCallee();
     if (!funcDcl) return false;
     std::string name = funcDcl->getDeclName().getAsString();
     const auto found = CUDA_RENAMES_MAP().find(name);
@@ -2734,15 +2832,13 @@ bool HipifyAction::cudaOverloadedHostFuncCall(const mat::MatchFinder::MatchResul
     auto overrideInfo = itNumArgs->second;
     auto counter = overrideInfo.counter;
     // check if SUPPORTED
-    auto* SM = Result.SourceManager;
-    clang::SourceLocation s;
     switch (overrideInfo.overloadType) {
       case ot_arguments_number:
       default:
       {
-        s = call->getBeginLoc();
-        ct::Replacement Rep(*SM, s, name.size(), counter.hipName.str());
-        clang::FullSourceLoc fullSL(s, *SM);
+        clang::SourceRange replacementRange = getWriteRange(*Result.SourceManager, { call->getBeginLoc(), call->getEndLoc() });
+        ct::Replacement Rep(*Result.SourceManager, replacementRange.getBegin(), name.size(), counter.hipName.str());
+        clang::FullSourceLoc fullSL(replacementRange.getBegin(), *Result.SourceManager);
         insertReplacement(Rep, fullSL);
         break;
       }
@@ -2767,8 +2863,9 @@ bool HipifyAction::half2Member(const mat::MatchFinder::MatchResult &Result) {
     clang::SmallString<40> XStr;
     llvm::raw_svector_ostream OS(XStr);
     OS << "reinterpret_cast<half&>(" << exprName << ")";
-    ct::Replacement Rep(*Result.SourceManager, sr.getBegin(), exprName.size(), OS.str());
-    clang::FullSourceLoc fullSL(sr.getBegin(), *Result.SourceManager);
+    clang::SourceRange replacementRange = getWriteRange(*Result.SourceManager, sr);
+    ct::Replacement Rep(*Result.SourceManager, replacementRange.getBegin(), exprName.size(), OS.str());
+    clang::FullSourceLoc fullSL(replacementRange.getBegin(), *Result.SourceManager);
     insertReplacement(Rep, fullSL);
     if (!NoWarningsUndocumented) {
       clang::DiagnosticsEngine& DE = getCompilerInstance().getDiagnostics();
@@ -2780,7 +2877,7 @@ bool HipifyAction::half2Member(const mat::MatchFinder::MatchResult &Result) {
   return false;
 }
 
-bool HipifyAction::dataTypeSelection(const mat::MatchFinder::MatchResult& Result) {
+bool HipifyAction::dataTypeSelection(const mat::MatchFinder::MatchResult &Result) {
   if (auto *vardecl = Result.Nodes.getNodeAs<clang::VarDecl>(sDataTypeSelection)) {
     clang::QualType QT = vardecl->getType();
     std::string name = QT.getAsString();
@@ -2792,10 +2889,9 @@ bool HipifyAction::dataTypeSelection(const mat::MatchFinder::MatchResult& Result
     const clang::TypeSourceInfo *si = vardecl->getTypeSourceInfo();
     const clang::TypeLoc tloc = si->getTypeLoc();
     const clang::SourceRange sr = tloc.getSourceRange();
-    const clang::SourceLocation sl = sr.getBegin();
-    auto *SM = Result.SourceManager;
-    ct::Replacement Rep(*SM, sl, name.size(), correct_name);
-    clang::FullSourceLoc fullSL(sl, *SM);
+    clang::SourceRange replacementRange = getWriteRange(*Result.SourceManager, sr);
+    ct::Replacement Rep(*Result.SourceManager, replacementRange.getBegin(), name.size(), correct_name);
+    clang::FullSourceLoc fullSL(replacementRange.getBegin(), *Result.SourceManager);
     insertReplacement(Rep, fullSL);
   }
   return false;
@@ -2837,6 +2933,12 @@ std::unique_ptr<clang::ASTConsumer> HipifyAction::CreateASTConsumer(clang::Compi
       mat::callee(
         mat::functionDecl(
           mat::hasAnyName(
+            sCudaFuncSetCacheConfig,
+            sCudaFuncSetSharedMemConfig,
+            sCudaFuncGetAttributes,
+            sCudaFuncSetAttribute,
+            sCudaLaunchKernelStr,
+            sCudaLaunchCooperativeKernel,
             sCudaGetSymbolAddress,
             sCudaGetSymbolSize,
             sCudaMemcpyFromSymbol,
@@ -3003,7 +3105,8 @@ std::unique_ptr<clang::ASTConsumer> HipifyAction::CreateASTConsumer(clang::Compi
             sCusparseSpMV,
             sCusparseSpMV_bufferSize,
             sCusparseSpMM_preprocess,
-            sCusparseSpSV_bufferSize
+            sCusparseSpSV_bufferSize,
+            sCudaGetDriverEntryPoint
           )
         )
       )
