@@ -366,11 +366,11 @@ void Statistics::setActive(const std::string &name) {
 
 bool Statistics::isToRoc(const hipCounter &counter) {
   return (counter.apiType == API_BLAS || counter.apiType == API_DNN || counter.apiType == API_SPARSE || counter.apiType == API_SOLVER ||
-          counter.apiType == API_RUNTIME || counter.apiType == API_COMPLEX) &&
-          ((TranslateToRoc && !TranslateToMIOpen && !isRocMiopenOnly(counter)) || TranslateToMIOpen);
+          counter.apiType == API_RUNTIME || counter.apiType == API_COMPLEX || counter.apiType == API_RAND) &&
+          ((TranslateToRoc && !TranslateToMIOpen) || TranslateToMIOpen);
 }
 
-bool Statistics::isHipExperimental(const hipCounter& counter) {
+bool Statistics::isHipExperimental(const hipCounter &counter) {
   return HIP_EXPERIMENTAL == (counter.supportDegree & HIP_EXPERIMENTAL);
 }
 
@@ -434,19 +434,15 @@ bool Statistics::isRemoved(const hipCounter &counter) {
          ROC_REMOVED == (counter.supportDegree & ROC_REMOVED));
 }
 
-bool Statistics::isHipSupportedV2Only(const hipCounter& counter) {
+bool Statistics::isHipSupportedV2Only(const hipCounter &counter) {
   return HIP_SUPPORTED_V2_ONLY == (counter.supportDegree & HIP_SUPPORTED_V2_ONLY);
 }
 
-bool Statistics::isRocMiopenOnly(const hipCounter& counter) {
-  return ROC_MIOPEN_ONLY == (counter.supportDegree & ROC_MIOPEN_ONLY);
-}
-
-bool Statistics::isCudaOverloaded(const hipCounter& counter) {
+bool Statistics::isCudaOverloaded(const hipCounter &counter) {
   return CUDA_OVERLOADED == (counter.supportDegree & CUDA_OVERLOADED);
 }
 
-std::string Statistics::getCudaVersion(const cudaVersions& ver) {
+std::string Statistics::getCudaVersion(const cudaVersions &ver) {
   switch (ver) {
     case CUDA_0:
     default:       return "";
@@ -488,6 +484,9 @@ std::string Statistics::getCudaVersion(const cudaVersions& ver) {
     case CUDA_121: return "12.1";
     case CUDA_122: return "12.2";
     case CUDA_123: return "12.3";
+    case CUDA_124: return "12.4";
+    case CUDA_125: return "12.5";
+    case CUDA_126: return "12.6";
     case CUDNN_10: return "1.0.0";
     case CUDNN_20: return "2.0.0";
     case CUDNN_30: return "3.0.0";
@@ -536,11 +535,17 @@ std::string Statistics::getCudaVersion(const cudaVersions& ver) {
     case CUDNN_895: return "8.9.5";
     case CUDNN_896: return "8.9.6";
     case CUDNN_897: return "8.9.7";
+    case CUDNN_900: return "9.0.0";
+    case CUDNN_910: return "9.1.0";
+    case CUDNN_920: return "9.2.0";
+    case CUDNN_930: return "9.3.0";
+    case CUDNN_940: return "9.4.0";
+    case CUDNN_950: return "9.5.0";
   }
   return "";
 }
 
-std::string Statistics::getHipVersion(const hipVersions& ver) {
+std::string Statistics::getHipVersion(const hipVersions &ver) {
   switch (ver) {
     case HIP_0:
     default:       return "";
@@ -607,6 +612,9 @@ std::string Statistics::getHipVersion(const hipVersions& ver) {
     case HIP_6000: return "6.0.0";
     case HIP_6002: return "6.0.2";
     case HIP_6010: return "6.1.0";
+    case HIP_6011: return "6.1.1";
+    case HIP_6020: return "6.2.0";
+    case HIP_6030: return "6.3.0";
   }
   return "";
 }
