@@ -197,8 +197,7 @@ enum SupportDegree {
   REMOVED = 0x400,
   HIP_EXPERIMENTAL = 0x800,
   HIP_SUPPORTED_V2_ONLY = 0x1000,
-  ROC_MIOPEN_ONLY = 0x2000,
-  CUDA_OVERLOADED = 0x4000
+  CUDA_OVERLOADED = 0x2000
 };
 
 enum cudaVersions {
@@ -241,7 +240,10 @@ enum cudaVersions {
   CUDA_121 = 12010,
   CUDA_122 = 12020,
   CUDA_123 = 12030,
-  CUDA_LATEST = CUDA_123,
+  CUDA_124 = 12040,
+  CUDA_125 = 12050,
+  CUDA_126 = 12060,
+  CUDA_LATEST = CUDA_126,
   CUDNN_10 = 100,
   CUDNN_20 = 200,
   CUDNN_30 = 300,
@@ -290,7 +292,13 @@ enum cudaVersions {
   CUDNN_895 = 895,
   CUDNN_896 = 896,
   CUDNN_897 = 897,
-  CUDNN_LATEST = CUDNN_897,
+  CUDNN_900 = 900,
+  CUDNN_910 = 910,
+  CUDNN_920 = 920,
+  CUDNN_930 = 930,
+  CUDNN_940 = 940,
+  CUDNN_950 = 950,
+  CUDNN_LATEST = CUDNN_950,
 };
 
 enum hipVersions {
@@ -358,7 +366,10 @@ enum hipVersions {
   HIP_6000 = 6000,
   HIP_6002 = 6002,
   HIP_6010 = 6010,
-  HIP_LATEST = HIP_6010,
+  HIP_6011 = 6011,
+  HIP_6020 = 6020,
+  HIP_6030 = 6030,
+  HIP_LATEST = HIP_6030,
 };
 
 struct cudaAPIversions {
@@ -407,7 +418,7 @@ public:
   // Add the counters from `other` onto the counters of this object.
   void add(const StatCounter &other);
   int getConvSum();
-  void print(std::ostream* csv, llvm::raw_ostream* printOut, const std::string &prefix);
+  void print(std::ostream *csv, llvm::raw_ostream *printOut, const std::string &prefix);
 };
 
 /**
@@ -443,13 +454,13 @@ public:
     * @param printOut Pointer to an output stream to print human-readable textual stats to. If null, no
     *                 such stats are produced.
     */
-  void print(std::ostream* csv, llvm::raw_ostream* printOut, bool skipHeader = false);
+  void print(std::ostream *csv, llvm::raw_ostream *printOut, bool skipHeader = false);
   // Print aggregated statistics for all registered counters.
-  static void printAggregate(std::ostream *csv, llvm::raw_ostream* printOut);
+  static void printAggregate(std::ostream *csv, llvm::raw_ostream *printOut);
   // The Statistics for each input file.
   static std::map<std::string, Statistics> stats;
   // The Statistics objects for the currently-being-processed input file.
-  static Statistics* currentStatistics;
+  static Statistics *currentStatistics;
   // Aggregate statistics over all entries in `stats` and return the resulting Statistics object.
   static Statistics getAggregate();
   /**
@@ -472,29 +483,27 @@ public:
   // Check whether the counter is ROC_UNSUPPORTED or not.
   static bool isRocUnsupported(const hipCounter &counter);
   // Check whether the counter is ROC_UNSUPPORTED/HIP_UNSUPPORTED/UNSUPPORTED or not.
-  static bool isUnsupported(const hipCounter& counter);
+  static bool isUnsupported(const hipCounter &counter);
   // Check whether the counter is CUDA_DEPRECATED or not.
-  static bool isCudaDeprecated(const hipCounter& counter);
+  static bool isCudaDeprecated(const hipCounter &counter);
   // Check whether the counter is HIP_DEPRECATED or not.
-  static bool isHipDeprecated(const hipCounter& counter);
+  static bool isHipDeprecated(const hipCounter &counter);
   // Check whether the counter is ROC_DEPRECATED or not.
-  static bool isRocDeprecated(const hipCounter& counter);
+  static bool isRocDeprecated(const hipCounter &counter);
   // Check whether the counter is DEPRECATED or not.
-  static bool isDeprecated(const hipCounter& counter);
+  static bool isDeprecated(const hipCounter &counter);
   // Check whether the counter is CUDA_REMOVED or not.
-  static bool isCudaRemoved(const hipCounter& counter);
+  static bool isCudaRemoved(const hipCounter &counter);
   // Check whether the counter is HIP_REMOVED or not.
-  static bool isHipRemoved(const hipCounter& counter);
+  static bool isHipRemoved(const hipCounter &counter);
   // Check whether the counter is ROC_REMOVED or not.
-  static bool isRocRemoved(const hipCounter& counter);
+  static bool isRocRemoved(const hipCounter &counter);
   // Check whether the counter is REMOVED or not.
-  static bool isRemoved(const hipCounter& counter);
+  static bool isRemoved(const hipCounter &counter);
   // Check whether the counter is HIP_SUPPORTED_V2_ONLY or not.
-  static bool isHipSupportedV2Only(const hipCounter& counter);
-  // Check whether the counter is ROC_MIOPEN_ONLY or not.
-  static bool isRocMiopenOnly(const hipCounter& counter);
+  static bool isHipSupportedV2Only(const hipCounter &counter);
   // Check whether the counter is CUDA_OVERLOADED or not.
-  static bool isCudaOverloaded(const hipCounter& counter);
+  static bool isCudaOverloaded(const hipCounter &counter);
   // Get string CUDA version.
   static std::string getCudaVersion(const cudaVersions &ver);
   // Get string HIP version.
